parse_target

Function parse_target 

pub fn parse_target(target: &str) -> Result<(PathBuf, usize)>
Parse "path/to/file.rs:42" into (PathBuf, usize).

Accepts optional column and trailing editor context after the line number:

  • src/foo.rs:42
  • src/foo.rs:42:7
  • src/foo.rs:42:7: some editor context

Splits on the last : so that Windows absolute paths (C:\foo\bar.rs:5) are handled correctly as long as the user puts the colon-number at the end.