pub struct Baseline {
pub generated_at: String,
pub detonated: usize,
pub ticking: usize,
}Expand description
The baseline snapshot stored in .timebomb-baseline.json.
Fields
generated_at: StringRFC 3339 timestamp of when this baseline was saved (set by the caller in main.rs).
detonated: usizeNumber of detonated fuses at the time the baseline was saved.
ticking: usizeNumber of ticking fuses at the time the baseline was saved.