Module config

Module config 

Structs

CliOverrides
CLI-level overrides that can be applied on top of a Config.
Config
Fully-resolved configuration after merging the config file with CLI overrides.
ConfigFile
The structure of .timebomb.toml on disk.

Functions

load_config
Load .timebomb.toml from root_dir if it exists, merge with defaults and CLI overrides.