load_config

Function load_config 

pub fn load_config(root_dir: &Path, overrides: &CliOverrides) -> Result<Config>
Load .timebomb.toml from root_dir if it exists, merge with defaults and CLI overrides.

Only root_dir/.timebomb.toml is checked. CWD fallback is the caller’s responsibility (handled in main.rs) so that tests using temp directories are not affected by a .timebomb.toml that happens to exist in the current working directory.

Returns a fully-resolved Config.