pub struct ConfigFile {
pub triggers: Option<Vec<String>>,
pub fuse_days: Option<u32>,
pub exclude: Option<Vec<String>>,
pub extensions: Option<Vec<String>>,
pub max_detonated: Option<usize>,
pub max_ticking: Option<usize>,
}Expand description
The structure of .timebomb.toml on disk.
Fields
triggers: Option<Vec<String>>Tags to scan for.
fuse_days: Option<u32>Warn (and optionally fail) if a fuse expires within this many days.
exclude: Option<Vec<String>>Glob patterns to exclude from scanning.
extensions: Option<Vec<String>>File extensions to scan. If empty/absent, scan all text files.
max_detonated: Option<usize>Ratchet: fail if the number of detonated fuses exceeds this limit.
max_ticking: Option<usize>Ratchet: fail if the number of ticking fuses exceeds this limit.