Functions
- git_
changed_ files - Run
git diff --name-only <git_ref>fromrepo_rootand return the set of relative paths of changed files. - is_
git_ repo - Returns true if
pathis inside a git repository (i.e.git rev-parsesucceeds in that directory). - validate_
git_ ref - Validate that a git ref contains only safe characters.