git_changed_files

Function git_changed_files 

pub fn git_changed_files(
    repo_root: &Path,
    git_ref: &str,
) -> Result<HashSet<PathBuf>>
Run git diff --name-only <git_ref> from repo_root and return the set of relative paths of changed files.

Returns an error if git is not available, the repo_root is not a git repo, or the ref is invalid.