validate_git_ref

Function validate_git_ref 

pub fn validate_git_ref(git_ref: &str) -> Result<()>
Validate that a git ref contains only safe characters.

Permits alphanumerics plus ., /, -, _ — the characters needed for branch names, tags, and SHAs. Rejects leading -- (option injection) and any special git syntax characters (@, ^, ~, :).