pub fn diff_reports(old: &Report, new: &Report) -> ReportDiffExpand description
Diff two reports. old is the previously persisted report, new is the freshly built one.
pub fn diff_reports(old: &Report, new: &Report) -> ReportDiffDiff two reports. old is the previously persisted report, new is the freshly built one.