pub struct ReportDiff {
pub newly_detonated: Vec<ReportAnnotation>,
pub resolved: Vec<ReportAnnotation>,
pub new_annotations: Vec<ReportAnnotation>,
pub snoozed: Vec<(ReportAnnotation, ReportAnnotation)>,
}Expand description
The result of diffing two reports.
Fields
newly_detonated: Vec<ReportAnnotation>Fuses that are detonated in the new report but were not in the old one (either newly added past their deadline, or crossed the deadline since last report).
resolved: Vec<ReportAnnotation>Fuses present in old report but absent in new (cleaned up / deleted).
new_annotations: Vec<ReportAnnotation>Fuses in new report that weren’t in old report at all (any status).
snoozed: Vec<(ReportAnnotation, ReportAnnotation)>Fuses whose date changed between old and new report (snoozed).