Module git

Module git 

Functions

git_changed_files
Run git diff --name-only <git_ref> from repo_root and return the set of relative paths of changed files.
is_git_repo
Returns true if path is inside a git repository (i.e. git rev-parse succeeds in that directory).
validate_git_ref
Validate that a git ref contains only safe characters.