pub fn run_hook_uninstall(path: &Path, yes: bool) -> Result<i32>Expand description
Uninstall the timebomb pre-commit hook.
- If the hook file does not exist or has no timebomb block, prints a message and exits 0.
- If the resulting cleaned file is empty (or only whitespace), deletes it.
- Otherwise writes the cleaned content back.